function ent = entropyCAMP(I, gaussKernel, bins, normalization, ...
    estimation, entropyMaes)

% Estimation of entropy for patch I
%
% Author: Christian Wachinger, CAMP, TU Mnchen, 2010
%
% References:
%  C. Wachinger, N. Navab
%  Structural Image Representation for Image Registration
%  CVPR Workshops, Mathematical Methods in Biomedical Image Analysis (MMBIA),
%  2010. 
%
%  C. Wachinger, N. Navab
%  Entropy and Laplacian Images: Structural Representations for Multi-Modal Registration
%  Medical Image Analysis, 2011.
%

if min(I(:)) == max(I(:))
    ent = 0;
else

    % Local normalization
    if (strcmp(normalization,'local'))
        I = double(I);
        I = I - min(I(:)) + 0.0001;
        I = ceil( I / max(I(:)) * bins);
    end

    % histogram
    histo = zeros(bins, 1);
    for i = 1:size(I,1)
        for j = 1:size(I,2)
            histo(I(i,j)) = histo(I(i,j)) + gaussKernel(i,j);
        end
    end

    % Parzen Windowing    
    if (strcmp(estimation,'parzen'))
        filt = [0.05 0.25 0.4 0.25 0.05]';
        histo = conv2(histo, filt, 'same');
    end

    % normalize
    histo = histo / sum(histo(:));

    % entropy calculation
    idx = find(histo > 0);
    
    switch lower(entropyMaes)
        case 'shannon'
            % Shannon
            ent = - sum(histo(idx) .* log(histo(idx)));
        case 'burg'
            % Burg
            ent = sum(log(histo(idx)));
        case 'renyi'
            % Renyi, alpha = 2
            ent = - log( sum(histo(idx).^2) );
    end

end