
% Main script for the calculation of entropy images. 
% Just run this script to see examples. 
%
% Author: Christian Wachinger, CAMP, TU Mnchen, 2010
%
% References:
%  C. Wachinger, N. Navab
%  Structural Image Representation for Image Registration
%  CVPR Workshops, Mathematical Methods in Biomedical Image Analysis (MMBIA),
%  2010. 
%
%  C. Wachinger, N. Navab
%  Entropy and Laplacian Images: Structural Representations for Multi-Modal Registration
%  Medical Image Analysis, 2011.
%

% load images from BrainWeb dataset
load images.mat

% Define parameters,  see 'calculateEntropyImage.m' for an explanation
patchSize = 9;
bins = 16; 
weighting = 'gaussian';
normalization = 'global';
estimation = 'parzen';
entropyMaes = 'shannon';

%% calculate entropy images
entT1 = calculateEntropyImage(imgT1,patchSize, bins, weighting, ...
    normalization, estimation, entropyMaes);

entT2 = calculateEntropyImage(imgT2,patchSize, bins, weighting, ...
    normalization, estimation, entropyMaes);

entPD = calculateEntropyImage(imgPD,patchSize, bins, weighting, ...
    normalization, estimation, entropyMaes);

%% visualize the result
figure, subplot(1,2,1), imshow(rot90(imgT1), [])
        subplot(1,2,2), imshow(rot90(entT1), [])
figure, subplot(1,2,1), imshow(rot90(imgT2), [])
        subplot(1,2,2), imshow(rot90(entT1), [])
figure, subplot(1,2,1), imshow(rot90(imgPD), [])
        subplot(1,2,2), imshow(rot90(entPD), [])

